@@ -151,18 +151,18 @@ async def process_application_heartbeat(app_id):
                 f"Completion function for application {app_id} did not return a valid response. Expected a string, got {type(response.response)}"
             )
             connection_test_payload["status"] = "failed"
-            connection_test_payload["error"] = (
-                "Completion function did not return a valid response. Expected a string, got {type(response.response)}"
-            )
+            connection_test_payload[
+                "error"
+            ] = "Completion function did not return a valid response. Expected a string, got {type(response.response)}"
 
         if response.response == "This is a string response from your application":
             LOGGER.error(
                 f"Completion function for application {app_id} returned a default response. This indicates the application is not properly connected."
             )
             connection_test_payload["status"] = "failed"
-            connection_test_payload["error"] = (
-                "Completion function returned a default response. "
-            )
+            connection_test_payload[
+                "error"
+            ] = "Completion function returned a default response. "
 
         if connection_test_payload.get("status") != "failed":
             connection_test_payload["response"] = response.response
@@ -693,17 +693,8 @@ async def lifespan(app: FastAPI):
                             )
                             continue
 
-                        # Wrap process_scenario to match the expected completion_fn interface
-                        def make_completion_fn(process_fn):
-                            def completion_fn(request):
-                                return process_fn(request)
-
-                            return completion_fn
-
                         apps[app_id] = {
-                            "completion_fn": make_completion_fn(
-                                agent_module.process_scenario
-                            ),
+                            "completion_fn": agent_module.process_scenario,
                             "name": app_name,
                         }
 
