@@ -401,6 +401,8 @@ def test_agent_wrapper(filename: str, app_id: str, app_name: str) -> Tuple[bool,
             return False, "Invalid response format"
 
     except Exception as e:
+        import traceback
+        traceback.print_exc()
         return False, f"Error: {str(e)}"
 
 
@@ -603,6 +605,8 @@ def _create_auth_server(config_key: str, rc_path: str) -> FastAPI:
 
             return {"written": True}
         except Exception as e:
+            import traceback
+            traceback.print_exc()
             error(f"Failed to process key configuration: {e}")
             return {"error": "Failed to process key configuration request"}
 
@@ -787,6 +791,8 @@ def start(
                 else:
                     console.print()
     except Exception:
+        import traceback
+        traceback.print_exc()
         # Do not block startup if we cannot load agents mapping
         pass
 
