@@ -531,12 +531,14 @@ class TestCli(unittest.TestCase):
             # Test Case 19: Valid agent with default template response
             template_file = os.path.join(tmpdir, "template.py")
             with open(template_file, "w") as f:
-                f.write("""
+                f.write(
+                    """
 from snowglobe.client import CompletionRequest, CompletionFunctionOutputs
 
 def process_scenario(request):
     return CompletionFunctionOutputs(response="Your response here")
-""")
+"""
+                )
 
             with mock.patch("os.getcwd", return_value=tmpdir):
                 result, message = cli.test_agent_wrapper(
